# depht-gui
This is a GUI for DEPhT (https://github.com/chg60/DEPhT)

DEPhT is a program written detect and extract prophages from bacterial genomes.
This GUI has been created specifically for DEPhT and can be used to either run the program to identify prophages or to train a model for the purpose.

This application requires the installation of depht.
